@@ -54,7 +54,10 @@ k9DVDAuthor::k9DVDAuthor(QObject *DVDStruct)  {
     xml=NULL;
     cancelled=false;
     error=false;
-    progress = new k9Progress(k9Dialogs::getMainWidget());
+    if (k9Tools::getBatchCopy())
+        progress=NULL;
+    else
+        progress = new k9Progress(k9Dialogs::getMainWidget());
 //    files.setAutoDelete(true);
 
 }
@@ -151,6 +154,9 @@ void k9DVDAuthor::addMenus(QDomElement &titleSet) {
     factor=DVD->getfactor(false,false,true);
     menu=xml->createElement("menus");
     titleSet.appendChild(menu);
+    video=xml->createElement("video");
+    video.setAttribute("format",DVD->getFormat());
+    menu.appendChild(video);
     pgc=xml->createElement("pgc");
     pgc.setAttribute("entry","title");
     menu.appendChild(pgc);
@@ -191,6 +197,10 @@ void k9DVDAuthor::addTitle(QDomElement &root, k9DVDTitle *title) {
         root.appendChild(titleSet);
         QDomElement titleMenu = xml->createElement("menus");
         titleSet.appendChild(titleMenu);
+        QDomElement video=xml->createElement("video");
+        titleMenu.appendChild(video);
+        video.setAttribute("format",l_track->getformat().toLower());
+
         QDomElement pgc = xml->createElement("pgc");
         titleMenu.appendChild(pgc);
         QDomElement pre = xml->createElement("pre");
@@ -350,6 +360,8 @@ void k9DVDAuthor::addTitle(QDomElement &root, k9DVDTitle *title) {
 #else
                     playPgm="/k9play";
 #endif
+                    if (!k9Tools::getBatchCopy())
+                        playPgm +=" --gui";
                     file=QString(qApp->applicationDirPath()+ playPgm+" --play --input %1 --dvdtitle %2 %3 %4  %5  %6 --vampsfactor %7 --inputsize %8 --chaptersize %9 ")
                          .arg(KShell::quoteArg(DVD->getDevice()))
                          .arg(title->getnumTitle())
@@ -432,9 +444,11 @@ void k9DVDAuthor::author() {
     QDir dir;
     dir.mkpath(workDir+DVD->getDVDTitle());
     dir.mkpath(m_tempPath);
-    progress->setTitle(i18n("Authoring"));
-    progress->setWindowTitle(KDialog::makeStandardCaption(i18n("Backup progression")));
-    progress->setProgress(0,100);
+    if (progress) {
+        progress->setTitle(i18n("Authoring"));
+        progress->setWindowTitle(KDialog::makeStandardCaption(i18n("Backup progression")));
+    }
+     setProgress(0,100);
     //progress->show();
 
     m_xml=new QTemporaryFile(m_tempPath+"/k9aXXXXXX.xml");
@@ -453,7 +467,10 @@ void k9DVDAuthor::author() {
     //run dvdauthor
     if (!cancelled  && !error) {
         QString c(config.getPrefDvdauthorPath(true));
-        proc=progress->getProcess();//  new QProcess(c,0);
+        if (k9Tools::getBatchCopy())
+            proc=new k9Process(this,0);
+        else
+            proc=progress->getProcess();//  new QProcess(c,0);
 
         *proc << c << "-x" <<  fileName;  //locateLocal("tmp", "k9copy/k9author.xml");
         connect( proc, SIGNAL(receivedStderr(char *, int)),
@@ -467,9 +484,12 @@ void k9DVDAuthor::author() {
         //if (m_totalSize >k9DVDSize::getMaxSize())
         //    m_totalSize=k9DVDSize::getMaxSize();
         proc-> setWorkingDirectory(workDir);
-        int result=progress->execute();
+        int result=execProcess();
         if ( result==-1 ) {
-            k9Dialogs::error(i18n("Dvdauthor error :\n") + lastMsg,i18n("authoring"));
+            if (k9Tools::getBatchCopy())
+                k9log::writeln(QString("dvdauthor error :%1").arg(lastMsg));
+            else
+                k9Dialogs::error(i18n("Dvdauthor error :\n") + lastMsg,i18n("authoring"));
 
         } else {
             cancelled=(result==0);
@@ -480,8 +500,10 @@ void k9DVDAuthor::author() {
                     //QMessageBox::critical( 0, tr2i18n("authoring"), tr2i18n("Authoring canceled"));
                     k9Dialogs::error( i18n("Authoring cancelled"),i18n("authoring"));                  
                 } else
-                    k9Dialogs::error( i18n("An error occured while running DVDAuthor:\n")+lastMsg ,i18n("authoring"));
-
+                    if (k9Tools::getBatchCopy())
+                        k9log::writeln(QString("dvdauthor error :%1").arg(lastMsg));
+                    else
+                        k9Dialogs::error( i18n("An error occured while running DVDAuthor:\n")+lastMsg ,i18n("authoring"));
             }
         }
         //        delete proc;
@@ -509,7 +531,8 @@ void k9DVDAuthor::DVDAuthorStderr(char *buffer, int buflen ) {
 
     int pos=m_stderr.indexOf("INFOPOS:");
     if (pos!=-1) {
-        progress->setTitle(i18n("Authoring"));
+        if (progress)
+            progress->setTitle(i18n("Authoring"));
         QString tmp=m_stderr.mid(pos);
         uint32_t totalBytes,totalSize;
         sscanf(tmp.toUtf8(),"INFOPOS: %d %d",&totalBytes,&totalSize);
@@ -530,10 +553,11 @@ void k9DVDAuthor::DVDAuthorStderr(char *buffer, int buflen ) {
         }
 
         m_percent*=100;
-        progress->setLabelText("");
-
-        progress->setProgress(m_percent,100);
-        progress->setElapsed(time2.toString("hh:mm:ss") +" / " +m_remain);
+        setProgress(m_percent,100);
+        if (progress) {
+            progress->setElapsed(time2.toString("hh:mm:ss") +" / " +m_remain);
+            progress->setLabelText("");
+        }
 
     }
     /*    else {
@@ -547,21 +571,25 @@ void k9DVDAuthor::DVDAuthorStderr(char *buffer, int buflen ) {
     if (m_stderr.contains("STAT:")) {
         pos=m_stderr.indexOf("fixing VOBU");
         if (pos!=-1) {
-            progress->setTitle(i18n("Authoring"));
-            progress->setLabelText(i18n("Fixing VOBUS"));
+            if (progress) {
+                progress->setTitle(i18n("Authoring"));
+                progress->setLabelText(i18n("Fixing VOBUS"));
+            } else
+                k9log::writeln("fixing VOBUS");
+
             end=m_stderr.indexOf("%");
             if (end!=-1) {
                 pos =end -2;
                 m_stderr=m_stderr.mid(pos,end-pos);
                 m_stderr=m_stderr.trimmed();
                 //progress->setLabelText(c);
-                progress->setProgress(m_stderr.toInt(),100);
+                setProgress(m_stderr.toInt(),100);
             }
         }
     }
 
     pos=m_stderr.indexOf("INFOIMAGE:");
-    if (pos!=-1) {
+    if (pos!=-1 && progress) {
         progress->setImage(m_stderr.mid(pos+10));
     }
 
@@ -576,8 +604,9 @@ void k9DVDAuthor::DVDAuthorStdout(char *buffer, int buflen) {
     pos=c.indexOf("STAT");
     if (pos!=-1) {
         c=c.mid(pos);
-        progress->setLabelText(c);
-        qApp->processEvents();
+        if (progress)
+            progress->setLabelText(c);
+        k9Tools::processEvents();
     }
 }
 
@@ -601,3 +630,32 @@ void k9DVDAuthor::setburnDVD( const bool& _newVal) {
 bool k9DVDAuthor::getError() {
     return error;
 }
+
+
+void k9DVDAuthor::setProgress(long _position,long _total) {
+    if (k9Tools::getBatchCopy())
+        k9log::writer(QString("current :%1").arg((double)_position/(double)_total));
+    else
+        progress->setProgress(_position,_total);
+}
+
+
+int k9DVDAuthor::execProcess() {
+    if (!k9Tools::getBatchCopy())
+        return progress->execute();
+    else {
+        if (! proc->isRunning()) {
+            k9log::writeln(proc->debug());
+            if (!proc->start())
+                return -1;
+        }
+
+        //the sync method allows to wait for the process end while receiving stdout.
+        proc->sync();
+
+        if (proc->normalExit())
+            return 1;
+        else
+            return -1;
+    }
+}
