@@ -14,6 +14,7 @@
 #define K9MP4DLG_H
 #include "k9common.h"
 #include "ui_mp4dlg.h"
+#include <QTimer>
 #include <qimage.h>
 #include <qdatetime.h>
 #include <QDialog>
@@ -41,7 +42,19 @@ signals:
 private:
     k9DrawImage *m_wimage;
     QTime m_timer;
+    QTimer m_timerUpdate;
     Ui::MP4Dlg Ui_MP4Dlg;
+
+    QString m_titleLabel;
+    QString m_fps;
+    QString m_remain;
+    int m_progress;
+    QString m_bitrate;
+    QString m_size;
+    QString m_fileName;
+    bool m_update;
+public slots:
+  void Update();
 protected slots:
   /*$PROTECTED_FUNCTIONS$*/
   void Cancel();
