@@ -13,8 +13,7 @@
 #define K9AUDIOCODECS_H
 
 #include "k9common.h"
-#include "k9config.h"
-#include <qobject.h>
+#include <QObject>
 
 /**
 	@author Jean-Michel PETIT <k9copy@free.fr>
