@@ -21,10 +21,8 @@
 #define k9BurnDVD_H
 
 #include "k9common.h"
-#include "k9progress.h"
-#include "k9config.h"
-#include <k9process.h>
-#include <klocale.h>
+#include "k9burnprogress.h"
+
 
 /**
 @author Jean-Michel PETIT
@@ -38,7 +36,7 @@ public:
   ~k9BurnDVD();
   virtual void setburnDevice( const QString& _newVal);
   virtual const QString& getburnDevice();
-  virtual QWidget* getDialog() {return progress;};
+  virtual QWidget* getDialog() {return progress;}
   void setworkDir( const QString& _newVal);
   void setvolId(QString  _newVal);
   void setUseK3b(bool _newVal);
@@ -48,12 +46,12 @@ public:
 
   void setSpeed(const QString& _value) { m_speed = _value;}
 
-	void setEject(bool theValue);
-	
+  void setEject(bool theValue);
+  bool isCancelled() { return cancelled;}
   
 private:
     QTime *time;
-    k9Progress *progress;
+    k9BurnProgress *progress;
     k9Process *proc;
     k9Process *proc2;
     QString volId;
@@ -80,10 +78,10 @@ private:
     QString m_speed;
     k9Config *m_config;
 private slots: // Private slots    
-    void growisoStderr(KProcess *proc, char *buffer, int buflen);
-    void growisoStdout(KProcess *proc, char *buffer, int buflen);  
-    void mkisoSizeStderr(KProcess *proc, char *buffer, int buflen);
-    void mkisoSizeStdout(KProcess *proc, char *buffer, int buflen);
+    void growisoStderr( char *buffer, int buflen);
+    void growisoStdout(char *buffer, int buflen);
+    void mkisoSizeStderr(char *buffer, int buflen);
+    void mkisoSizeStdout(char *buffer, int buflen);
 };
 
 #endif
