@@ -66,13 +66,14 @@ private:
     bool m_prefMpegChapters;
     bool m_prefUserOps;
     bool m_prefShowOutput;
+    bool m_GtkStyle;
     QString  m_prefMp4Width;
     QString  m_prefMp4Height;
     QString  m_prefMp4AudioBitrate;
     QString  m_prefMp4VideoBitrate;
     QString  m_prefAudioFormat;
     QString m_prefCodecAudio,m_prefCodecVideo,m_prefCodecLabel;
-    QString m_prefAudioLang,m_prefSubtitleLang;
+    QStringList m_prefAudioLang,m_prefSubtitleLang;
     QStringList m_devices;
     QStringList m_devicesLabels;
     QStringList m_devicesIO;
@@ -126,6 +127,13 @@ public:
     void setMpegChapters ( bool _value ) {
         m_prefMpegChapters=_value;
     }
+    bool getGtkStyle() const {
+        return m_GtkStyle;
+    }
+
+    void setGtkStyle ( bool _value ) {
+        m_GtkStyle=_value;
+    }
 
     bool getKeepMenus() const {
         return m_keepMenus;
@@ -623,21 +631,21 @@ public:
         return m_prefUserOps;
     }
 
-    void setPrefAudioLang ( const QString& theValue ) {
+    void setPrefAudioLang ( const QStringList& theValue ) {
         m_prefAudioLang = theValue;
     }
 
 
-    QString getPrefAudioLang() const {
+    QStringList getPrefAudioLang() const {
         return m_prefAudioLang;
     }
 
-    void setPrefSubtitleLang ( const QString& theValue ) {
+    void setPrefSubtitleLang ( const QStringList& theValue ) {
         m_prefSubtitleLang = theValue;
     }
 
 
-    QString getPrefSubtitleLang() const {
+    QStringList getPrefSubtitleLang() const {
         return m_prefSubtitleLang;
     }
 
