@@ -12,7 +12,6 @@
 #include "k9dvdread.h"
 #include "dvdread.h"
 #include "k9ifo2.h"
-#include <QtDebug>
 
 k9DVDRead::k9DVDRead(){
 	m_dvd=NULL;
@@ -66,7 +65,11 @@ void k9DVDRead::openDevice(const QString & _device) {
     
             for (int iTS=1 ; iTS<=nrTS;iTS++) {
                 k9Ifo2 *ifo=new k9Ifo2(this);
-                ifo->openIFO(iTS);
+                if (!ifo->openIFO(iTS)) {
+                    close();
+                    return;
+                }
+
                 m_ifos.append(ifo);
             }
         }
