@@ -12,8 +12,7 @@
 #ifndef K9DVDSIZE_H
 #define K9DVDSIZE_H
 
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QObject>
 /**
 @author Jean-Michel PETIT
 */
