@@ -14,9 +14,8 @@
 
 #include "k9common.h"
 #include "k9dvd.h"
-#include <qdatetime.h>
-#include <qstringlist.h>
-//#include <qptrlist.h>
+#include <QDateTime>
+#include <QStringList>
 #include "k9dvdtitle.h"
 		
 class k9DVDTitleset 
