@@ -24,6 +24,9 @@ public:
     static void add(QString s,k9logLevel::type level);
     static k9logEntry* dequeue ();
     static int count();
+    static void write(QString s);
+    static void writer(QString s);
+    static void writeln(QString s);
 };
 
 #endif // K9LOG_H
