@@ -13,9 +13,9 @@
 #define K9VIDEOCODECS_H
 
 #include "k9common.h"
-#include <qobject.h>
-#include <qmap.h>
-#include "k9config.h"
+#include <QObject>
+#include <QMap>
+
 
 /**
 	@author Jean-Michel PETIT <k9copy@free.fr>
