@@ -39,7 +39,8 @@
 #include "remap.h"
 #include "dvdread.h"
 
-static dvdnav_status_t dvdnav_clear(dvdnav_t * this) {
+#define dvdnav_clear(a) ___dvdnav_clear(a)
+static dvdnav_status_t ___dvdnav_clear(dvdnav_t * this) {
   /* clear everything except file, vm, mutex, readahead */
 
   if (this->file) DVDCloseFile(this->file);
@@ -63,7 +64,7 @@ static dvdnav_status_t dvdnav_clear(dvdnav_t * this) {
 } 
 
 
-dvdnav_status_t dvdnav_open(dvdnav_t** dest, const char *path,dvd_reader_t *dvd) {
+dvdnav_status_t ___dvdnav_open(dvdnav_t** dest, const char *path,dvd_reader_t *dvd) {
   dvdnav_t *this;
   struct timeval time;
   
@@ -119,7 +120,7 @@ dvdnav_status_t dvdnav_open(dvdnav_t** dest, const char *path,dvd_reader_t *dvd)
 
 
 
-dvdnav_status_t dvdnav_close(dvdnav_t *this) {
+dvdnav_status_t ___dvdnav_close(dvdnav_t *this) {
 
 #ifdef LOG_DEBUG
   fprintf(MSG_OUT, "libdvdnav: close:called\n");
@@ -155,7 +156,7 @@ dvdnav_status_t dvdnav_close(dvdnav_t *this) {
   return DVDNAV_STATUS_OK;
 }
 
-dvdnav_status_t dvdnav_reset(dvdnav_t *this) {
+dvdnav_status_t ___dvdnav_reset(dvdnav_t *this) {
   dvdnav_status_t result;
 
 #ifdef LOG_DEBUG
@@ -186,7 +187,7 @@ dvdnav_status_t dvdnav_reset(dvdnav_t *this) {
   return result;
 }
 
-dvdnav_status_t dvdnav_path(dvdnav_t *this, const char** path) {
+dvdnav_status_t ___dvdnav_path(dvdnav_t *this, const char** path) {
 
   if(!this || !path) {
     printerr("Passed a NULL pointer.");
@@ -198,7 +199,8 @@ dvdnav_status_t dvdnav_path(dvdnav_t *this, const char** path) {
   return DVDNAV_STATUS_OK;
 }
 
-const char* dvdnav_err_to_string(dvdnav_t *this) {
+
+const char* ___dvdnav_err_to_string(dvdnav_t *this) {
   
   if(!this)
     return "Hey! You gave me a NULL pointer you naughty person!";
@@ -207,7 +209,7 @@ const char* dvdnav_err_to_string(dvdnav_t *this) {
 }
 
 /* converts a dvd_time_t to PTS ticks */
-int64_t dvdnav_convert_time(dvd_time_t *time) {
+int64_t ___dvdnav_convert_time(dvd_time_t *time) {
   int64_t result;
   int64_t frames;
   
@@ -236,7 +238,8 @@ int64_t dvdnav_convert_time(dvd_time_t *time) {
  * Most of the code in here is copied from xine's MPEG demuxer
  * so any bugs which are found in that should be corrected here also.
  */
-static int32_t dvdnav_decode_packet(dvdnav_t *this, uint8_t *p, dsi_t *nav_dsi, pci_t *nav_pci) {
+#define dvdnav_decode_packet(a,b,c,d) ___dvdnav_decode_packet(a,b,c,d)
+static int32_t ___dvdnav_decode_packet(dvdnav_t *this, uint8_t *p, dsi_t *nav_dsi, pci_t *nav_pci) {
   int32_t        bMpeg1 = 0;
   uint32_t       nHeaderLen;
   uint32_t       nPacketLen;
@@ -302,7 +305,8 @@ static int32_t dvdnav_decode_packet(dvdnav_t *this, uint8_t *p, dsi_t *nav_dsi,
 /* DSI is used for most angle stuff. 
  * PCI is used for only non-seemless angle stuff
  */ 
-static int32_t dvdnav_get_vobu(dvdnav_t *this, dsi_t *nav_dsi, pci_t *nav_pci, dvdnav_vobu_t *vobu) {
+#define dvdnav_get_vobu(a,b,c,d) ___dvdnav_get_vobu(a,b,c,d)
+static int32_t ___dvdnav_get_vobu(dvdnav_t *this, dsi_t *nav_dsi, pci_t *nav_pci, dvdnav_vobu_t *vobu) {
   uint32_t next;
   int32_t angle, num_angle;
 
@@ -379,7 +383,7 @@ static int32_t dvdnav_get_vobu(dvdnav_t *this, dsi_t *nav_dsi, pci_t *nav_pci, d
  * The drawback is the additional memcopy.
  */
 
-dvdnav_status_t dvdnav_get_next_block(dvdnav_t *this, uint8_t *buf,
+dvdnav_status_t ___dvdnav_get_next_block(dvdnav_t *this, uint8_t *buf,
 				      int32_t *event, int32_t *len) {
   unsigned char *block;
   dvdnav_status_t status;
@@ -394,7 +398,7 @@ dvdnav_status_t dvdnav_get_next_block(dvdnav_t *this, uint8_t *buf,
   return status;
 }
  
-dvdnav_status_t dvdnav_get_next_cache_block(dvdnav_t *this, uint8_t **buf,
+dvdnav_status_t ___dvdnav_get_next_cache_block(dvdnav_t *this, uint8_t **buf,
 					    int32_t *event, int32_t *len) {
   dvd_state_t *state;
   int32_t result;
@@ -813,7 +817,7 @@ dvdnav_status_t dvdnav_get_next_cache_block(dvdnav_t *this, uint8_t **buf,
   return DVDNAV_STATUS_OK;
 }
 
-dvdnav_status_t dvdnav_get_title_string(dvdnav_t *this, const char **title_str) {
+dvdnav_status_t ___dvdnav_get_title_string(dvdnav_t *this, const char **title_str) {
   
   if(!this || !title_str) {
     printerr("Passed a NULL pointer.");
@@ -824,7 +828,7 @@ dvdnav_status_t dvdnav_get_title_string(dvdnav_t *this, const char **title_str)
   return DVDNAV_STATUS_OK;
 }
 
-uint8_t dvdnav_get_video_aspect(dvdnav_t *this) {
+uint8_t ___dvdnav_get_video_aspect(dvdnav_t *this) {
   uint8_t         retval;
   
   if(!this) {
@@ -843,7 +847,7 @@ uint8_t dvdnav_get_video_aspect(dvdnav_t *this) {
   return retval;
 }
 
-uint8_t dvdnav_get_video_scale_permission(dvdnav_t *this) {
+uint8_t ___dvdnav_get_video_scale_permission(dvdnav_t *this) {
   uint8_t         retval;
   
   if(!this) {
@@ -862,7 +866,7 @@ uint8_t dvdnav_get_video_scale_permission(dvdnav_t *this) {
   return retval;
 }
 
-uint16_t dvdnav_audio_stream_to_lang(dvdnav_t *this, uint8_t stream) {
+uint16_t ___dvdnav_audio_stream_to_lang(dvdnav_t *this, uint8_t stream) {
   audio_attr_t  attr;
   
   if(!this) {
@@ -884,7 +888,7 @@ uint16_t dvdnav_audio_stream_to_lang(dvdnav_t *this, uint8_t stream) {
   return attr.lang_code;
 }
 
-uint16_t dvdnav_spu_stream_to_lang(dvdnav_t *this, uint8_t stream) {
+uint16_t ___dvdnav_spu_stream_to_lang(dvdnav_t *this, uint8_t stream) {
   subp_attr_t  attr;
   
   if(!this) {
@@ -906,7 +910,7 @@ uint16_t dvdnav_spu_stream_to_lang(dvdnav_t *this, uint8_t stream) {
   return attr.lang_code;
 }
 
-int8_t dvdnav_get_audio_logical_stream(dvdnav_t *this, uint8_t audio_num) {
+int8_t ___dvdnav_get_audio_logical_stream(dvdnav_t *this, uint8_t audio_num) {
   int8_t       retval;
   
   if(!this) {
@@ -930,7 +934,7 @@ int8_t dvdnav_get_audio_logical_stream(dvdnav_t *this, uint8_t audio_num) {
   return retval;
 }
 
-int8_t dvdnav_get_spu_logical_stream(dvdnav_t *this, uint8_t subp_num) {
+int8_t ___dvdnav_get_spu_logical_stream(dvdnav_t *this, uint8_t subp_num) {
   int8_t       retval;
 
   if(!this) {
@@ -954,7 +958,7 @@ int8_t dvdnav_get_spu_logical_stream(dvdnav_t *this, uint8_t subp_num) {
   return retval;
 }
 
-int8_t dvdnav_get_active_audio_stream(dvdnav_t *this) {
+int8_t ___dvdnav_get_active_audio_stream(dvdnav_t *this) {
   int8_t        retval;
 
   if(!this) {
@@ -978,7 +982,7 @@ int8_t dvdnav_get_active_audio_stream(dvdnav_t *this) {
   return retval;
 }
 
-int8_t dvdnav_get_active_spu_stream(dvdnav_t *this) {
+int8_t ___dvdnav_get_active_spu_stream(dvdnav_t *this) {
   int8_t        retval;
 
   if(!this) {
@@ -1002,7 +1006,8 @@ int8_t dvdnav_get_active_spu_stream(dvdnav_t *this) {
   return retval;
 }
 
-static int8_t dvdnav_is_domain(dvdnav_t *this, domain_t domain) {
+#define dvdnav_is_domain(a,b) ___dvdnav_is_domain(a,b)
+static int8_t ___dvdnav_is_domain(dvdnav_t *this, domain_t domain) {
   int8_t        retval;
   
   if(!this) {
@@ -1022,24 +1027,25 @@ static int8_t dvdnav_is_domain(dvdnav_t *this, domain_t domain) {
 }
 
 /* First Play domain. (Menu) */
-int8_t dvdnav_is_domain_fp(dvdnav_t *this) {
+int8_t ___dvdnav_is_domain_fp(dvdnav_t *this) {
   return dvdnav_is_domain(this, FP_DOMAIN);
 }
 /* Video management Menu domain. (Menu) */
-int8_t dvdnav_is_domain_vmgm(dvdnav_t *this) {
+int8_t ___dvdnav_is_domain_vmgm(dvdnav_t *this) {
   return dvdnav_is_domain(this, VMGM_DOMAIN);
 }
 /* Video Title Menu domain (Menu) */
-int8_t dvdnav_is_domain_vtsm(dvdnav_t *this) {
+
+int8_t ___dvdnav_is_domain_vtsm(dvdnav_t *this) {
   return dvdnav_is_domain(this, VTSM_DOMAIN);
 }
 /* Video Title domain (playing movie). */
-int8_t dvdnav_is_domain_vts(dvdnav_t *this) { 
+int8_t ___dvdnav_is_domain_vts(dvdnav_t *this) {
   return dvdnav_is_domain(this, VTS_DOMAIN);
 }
 
 /* Generally delegate angle information handling to VM */
-dvdnav_status_t dvdnav_angle_change(dvdnav_t *this, int32_t angle) {
+dvdnav_status_t ___dvdnav_angle_change(dvdnav_t *this, int32_t angle) {
   int32_t num, current;
   
   if(!this) {
@@ -1062,7 +1068,7 @@ dvdnav_status_t dvdnav_angle_change(dvdnav_t *this, int32_t angle) {
   return DVDNAV_STATUS_OK;
 }
 
-dvdnav_status_t dvdnav_get_angle_info(dvdnav_t *this, int32_t *current_angle,
+dvdnav_status_t ___dvdnav_get_angle_info(dvdnav_t *this, int32_t *current_angle,
 				      int32_t *number_of_angles) {
   if(!this || !current_angle || !number_of_angles) {
     printerr("Passed a NULL pointer.");
@@ -1076,17 +1082,17 @@ dvdnav_status_t dvdnav_get_angle_info(dvdnav_t *this, int32_t *current_angle,
   return DVDNAV_STATUS_OK;
 }
 
-pci_t* dvdnav_get_current_nav_pci(dvdnav_t *this) {
+pci_t* ___dvdnav_get_current_nav_pci(dvdnav_t *this) {
   if(!this) return 0;
   return &this->pci;
 }
 
-dsi_t* dvdnav_get_current_nav_dsi(dvdnav_t *this) {
+dsi_t* ___dvdnav_get_current_nav_dsi(dvdnav_t *this) {
   if(!this) return 0;
   return &this->dsi;
 }
 
-uint32_t dvdnav_get_next_still_flag(dvdnav_t *this) {
+uint32_t ___dvdnav_get_next_still_flag(dvdnav_t *this) {
   if(!this) return -1;
   return this->position_next.still;
 }
