@@ -19,6 +19,7 @@
 #include "k9common.h"
 #include "k9cddrive.h"
 #ifdef BACKLITE
+#include <QLabel>
 #else
 #include <kapplication.h>
 #include <KToggleAction>
@@ -85,6 +86,7 @@ private slots:
     void optionsConfigureKeys();
     void optionsConfigureToolbars();
     void newToolbarConfig();
+    void setGtkStyle(bool);
 public slots:
     void fileOpen();
     void preferences();
@@ -99,6 +101,7 @@ private:
     void createCopyWindows();
     void removeToolWindows();
     void saveDock();
+    bool foundGtkStyle();
     KAction *CopyAction;
     KAction *PlayTitleAction;
     KAction *ejectAction;
@@ -122,6 +125,7 @@ private:
     bool m_usePhonon;
     bool m_useMplayer;
     bool m_useDvdAuthor;
+
     QMap  <QString,KAction*> m_actions;
     //QPtrList <KMdiToolViewAccessor> m_ToolViews;
     k9CdDrives *m_drives;
