@@ -517,6 +517,7 @@ void k9Main::Open() {
         font.setWeight ( QFont::Bold );
         tsItem->setFont ( 1,font );
 
+
         tsItem->setText ( 1,"   "+dvd->gettitleset ( i )->getsize_mb() +" " +i18n ( "MB" ) );
         tsItem->setTextAlignment ( 1,Qt::AlignRight );
         tsItem->obj=dvd->gettitleset ( i ) ;
@@ -957,13 +958,13 @@ void k9Main::checkAll ( bool state ) {
         switch ( litem->streamType ) {
         case SUB:
             if ( state )
-                litem->listItem->setOn ( ( config.getPrefSubtitleLang().trimmed() =="" ) || ( litem->subtitle->getlangCod() ==config.getPrefSubtitleLang() ) );
+                litem->listItem->setOn (config.getPrefSubtitleLang().contains(litem->subtitle->getlangCod()) || (config.getPrefSubtitleLang().count()==0));
             else
                 litem->listItem->setOn ( state );
             break;
         case AUD:
             if ( state )
-                litem->listItem->setOn ( ( config.getPrefAudioLang().trimmed() =="" ) || ( litem->audioStream->getlangCod() ==config.getPrefAudioLang() ) );
+                litem->listItem->setOn ( config.getPrefAudioLang().contains( litem->audioStream->getlangCod() ) || (config.getPrefAudioLang().count()==0));
             else
                 litem->listItem->setOn ( state );
             break;
@@ -1006,13 +1007,13 @@ void k9Main::checkTS ( bool _state,ckLvItem *_item ) {
             switch ( litem->streamType ) {
             case SUB:
                 if ( _state )
-                    litem->listItem->setOn ( ( config.getPrefSubtitleLang().trimmed() =="" ) || ( litem->subtitle->getlangCod() ==config.getPrefSubtitleLang() ) );
+                    litem->listItem->setOn ( config.getPrefSubtitleLang().contains( litem->subtitle->getlangCod()) ||  (config.getPrefSubtitleLang().count()==0));
                 else
                     litem->listItem->setOn ( _state );
                 break;
             case AUD:
                 if ( _state )
-                    litem->listItem->setOn ( ( config.getPrefAudioLang().trimmed() =="" ) || ( litem->audioStream->getlangCod() ==config.getPrefAudioLang() ) );
+                    litem->listItem->setOn ( config.getPrefAudioLang().contains( litem->audioStream->getlangCod()) || (config.getPrefAudioLang().count()==0));
                 else
                     litem->listItem->setOn ( _state );
                 break;
