@@ -22,7 +22,7 @@ k9prefDirs::k9prefDirs(QWidget* parent)
     Ui_prefDirs.setupUi(this);
     k9Config config;
 #ifdef BACKLITE
-    Ui_prefDirs.urDirDVD->setMode(KUrlRequester::DIRECTORY);
+ //   Ui_prefDirs.urDirDVD->setMode(KUrlRequester::DIRECTORY);
     Ui_prefDirs.urDirISO->setMode(KUrlRequester::DIRECTORY);
     Ui_prefDirs.urDirMPEG4->setMode(KUrlRequester::DIRECTORY);
     Ui_prefDirs.urDirMPEG2->setMode(KUrlRequester::DIRECTORY);
@@ -35,7 +35,7 @@ k9prefDirs::k9prefDirs(QWidget* parent)
     Ui_prefDirs.urWodim->setMode(KUrlRequester::OPEN);
     Ui_prefDirs.urK3b->setMode(KUrlRequester::OPEN);
 #else
-    Ui_prefDirs.urDirDVD->setMode(KFile::Directory);
+   // Ui_prefDirs.urDirDVD->setMode(KFile::Directory);
     Ui_prefDirs.urDirISO->setMode(KFile::Directory);
     Ui_prefDirs.urDirMPEG4->setMode(KFile::Directory);
     Ui_prefDirs.urDirMPEG2->setMode(KFile::Directory);
@@ -48,7 +48,7 @@ k9prefDirs::k9prefDirs(QWidget* parent)
     Ui_prefDirs.urWodim->setMode(KFile::ExistingOnly | KFile::File);
     Ui_prefDirs.urK3b->setMode(KFile::ExistingOnly | KFile::File);
 #endif
-    Ui_prefDirs.urDirDVD->setUrl(KUrl(config.getPrefOutput()));
+    //Ui_prefDirs.urDirDVD->setUrl(KUrl(config.getPrefOutput()));
     Ui_prefDirs.urDirISO->setUrl(KUrl(config.getPrefOutputIso()));
     Ui_prefDirs.urDirMPEG4->setUrl(KUrl(config.getPrefOutputMpeg4()));
     Ui_prefDirs.urDirMPEG2->setUrl(KUrl(config.getPrefOutputMpeg2()));
@@ -71,7 +71,7 @@ k9prefDirs::~k9prefDirs()
 
 void k9prefDirs::save() {
     k9Config config;
-    config.setPrefOutput( Ui_prefDirs.urDirDVD->url().path());
+   // config.setPrefOutput( Ui_prefDirs.urDirDVD->url().path());
 
     config.setPrefOutputAudio ( Ui_prefDirs.urDirAudio->url().path());
     config.setPrefOutputIso( Ui_prefDirs.urDirISO->url().path());
