@@ -33,10 +33,12 @@ protected:
 
 protected slots:
   /*$PROTECTED_SLOTS$*/
-
+  void lwAudioLangChanged (QListWidgetItem *item);
+  void lwSubtitleLangChanged (QListWidgetItem *item);
 private:
   Ui::prefDVD Ui_prefDVD;
-  void loadLanguages(QComboBox *_combo);
+  void loadLanguages(QListWidget *_list,const QStringList &_prefered);
+  bool m_loading;
 };
 
 #endif
