@@ -19,10 +19,13 @@
  ***************************************************************************/
 #include "k9phonon.h"
 #include "k9dvdtitle.h"
+#ifdef BACKLITE
+#include <phonon/volumeslider.h>
+#include <phonon/seekslider.h>
+#else
 #include <Phonon/VolumeSlider>
 #include <Phonon/SeekSlider>
-
-
+#endif
 k9Phonon::k9Phonon(QWidget *parent)
  : QWidget(parent)
 {
@@ -44,8 +47,13 @@ k9Phonon::k9Phonon(QWidget *parent)
     Phonon::SeekSlider *m_seekSlider = new Phonon::SeekSlider(this);
     m_seekSlider->setMediaObject(m_media);
     m_volumeSlider->setAudioOutput(m_aoutput);
-  Ui_phonon.bPlay->setIcon(SmallIcon("media-playback-start"));
+#ifdef BACKLITE
+    Ui_phonon.bPlay->setIcon(QIcon(":/icons/icon-start"));
+    Ui_phonon.bStop->setIcon(QIcon(":/icons/icon-stop"));
+#else
+    Ui_phonon.bPlay->setIcon(SmallIcon("media-playback-start"));
     Ui_phonon.bStop->setIcon(SmallIcon("media-playback-stop"));
+#endif
     QGridLayout *Grid=new QGridLayout(Ui_phonon.frControl);
     Grid->addWidget(Ui_phonon.bStop,0,0);
     Grid->addWidget(Ui_phonon.bPlay,0,1);
