@@ -75,7 +75,10 @@ k9play::k9play(QObject *parent): QThread(parent)  {
     m_aborted=false;
     m_exitOnEnd=false;
     m_eventLoop=NULL;
-    m_saveImage=new k9SaveImage();
+    if (!k9Tools::getBatchCopy())
+        m_saveImage=new k9SaveImage();
+    else
+        m_saveImage=NULL;
 }
 
 void k9play::abort() {
@@ -102,7 +105,7 @@ void k9play::writeOutput(QString const & _msg) {
 
 k9play::~k9play() {
     //  m_stderr.close();
-    delete m_saveImage;
+    if (m_saveImage) delete m_saveImage;
 }
 
 void k9play::setexitOnEnd(bool _value) {
@@ -202,12 +205,15 @@ void k9play::getPosition(uint32_t *_position,uint32_t *_length) {
 
 }
 
+
 void k9play::execute() {
     //playCell();
     m_terminated=false;
-    if (m_mainThread)
-        play();
-    else
+    if (m_mainThread) {
+    //    play();
+        m_vamps= new k9vamps(NULL,m_useCache);
+    }
+
         start();
     //play();
 }
@@ -294,12 +300,18 @@ void k9play::play() {
     } else
         m_output=NULL;
 
-    k9vamps vamps(parent,m_useCache);
-    vamps.reset();
-    vamps.setPreserve( false);
-    vamps.setOutput(m_output);
-    m_saveImage->play();
-    vamps.setSaveImage(m_saveImage);
+    k9vamps *vamps;
+    if (m_mainThread)
+        vamps=m_vamps;
+    else
+        vamps=parent->getVamps();
+
+    vamps->reset();
+    vamps->setPreserve( false);
+    vamps->setOutput(m_output);
+    if (!k9Tools::getBatchCopy())
+        m_saveImage->play();
+    vamps->setSaveImage(m_saveImage);
 
     // if reading of previous cell reached end of chapter, don't seek for cell
     if (m_chapter !=0 && m_cell !=0) {
@@ -322,26 +334,27 @@ void k9play::play() {
         factor = (double) (m_totalSize - (status.bytesRead +status.bytesSkipped)) / (double) (m_dvdSize-status.bytesWritten) ;
         if (factor <1) factor =1;
         kdebug(QString("shrink factor %1 totalSize:%2 (status.bytesRead +status.bytesSkipped):%3 m_dvdSize:%4 status.bytesWritten:%5").arg(factor).arg(m_totalSize).arg(status.bytesRead +status.bytesSkipped).arg(m_dvdSize).arg(status.bytesWritten) );
-        vamps.setVapFactor(factor);
+        vamps->setVapFactor(factor);
     } else {
-        vamps.setVapFactor(m_vampsFactor);
+        vamps->setVapFactor(m_vampsFactor);
         kdebug(QString("vamps factor %1\n").arg(m_vampsFactor));
     }
 
 
-    vamps.setInputSize(m_inputSize);
+    vamps->setInputSize(m_inputSize);
     foreach ( QString audio, m_audioFilter) {
-        vamps.addAudio(audio.toInt());
+        vamps->addAudio(audio.toInt());
     }
 
     foreach ( QString sub, m_subpictureFilter) {
-        vamps.addSubpicture(sub.toInt());
+        vamps->addSubpicture(sub.toInt());
     }
 
     /* open dvdnav handle */
     if (dvdnav_open(&dvdnav, m_device.toUtf8(),NULL) != DVDNAV_STATUS_OK) {
         writeOutput("ERR:Error on dvdnav_open\n");
         emit sigError(i18n("Error opening the DVD"));
+        end();
         return ;
     }
 
@@ -349,19 +362,27 @@ void k9play::play() {
     if (dvdnav_set_readahead_flag(dvdnav, DVD_READ_CACHE) != DVDNAV_STATUS_OK) {
         writeOutput( QString("ERR:Error on dvdnav_set_readahead_flag: %1\n").arg(dvdnav_err_to_string(dvdnav)));
         emit sigError(i18n("Error on dvdnav_set_readahead_flag: %1").arg(dvdnav_err_to_string(dvdnav)));
+        end();
         return;
     }
 
     /* set the language */
     k9Config config;
-    if (dvdnav_menu_language_select(dvdnav, config.getPrefAudioLang().toAscii().data()) != DVDNAV_STATUS_OK ||
-            dvdnav_audio_language_select(dvdnav, config.getPrefAudioLang().toAscii().data()) != DVDNAV_STATUS_OK ||
-            dvdnav_spu_language_select(dvdnav, config.getPrefSubtitleLang().toAscii().data()) != DVDNAV_STATUS_OK) {
+    QString audioLang="en";
+    if (config.getPrefAudioLang().count()>0)
+        config.getPrefAudioLang().first();
+    QString subtitleLang="";
+    if (config.getPrefSubtitleLang().count()>0)
+        config.getPrefSubtitleLang().first();
+    if (dvdnav_menu_language_select(dvdnav, audioLang.toAscii().data()) != DVDNAV_STATUS_OK ||
+            dvdnav_audio_language_select(dvdnav, audioLang.toAscii().data()) != DVDNAV_STATUS_OK ||
+            dvdnav_spu_language_select(dvdnav, subtitleLang.toAscii().data()) != DVDNAV_STATUS_OK) {
         if (dvdnav_menu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
                 dvdnav_audio_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
                 dvdnav_spu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK) {
             writeOutput( QString("ERR:Error on setting languages: %1\n").arg(dvdnav_err_to_string(dvdnav)));
             emit sigError(i18n("Error on setting languages: %1").arg(dvdnav_err_to_string(dvdnav)));
+            end();
             return ;
         }
     }
@@ -370,6 +391,7 @@ void k9play::play() {
     if (dvdnav_set_PGC_positioning_flag(dvdnav, 1) != DVDNAV_STATUS_OK) {
         writeOutput(QString("ERR:Error on dvdnav_set_PGC_positioning_flag: %1\n").arg(dvdnav_err_to_string(dvdnav)));
         emit sigError(i18n("Error on dvdnav_set_PGC_positioning_flag: %1").arg(dvdnav_err_to_string(dvdnav)));;
+        end();
         return ;
     }
 
@@ -404,6 +426,7 @@ void k9play::play() {
         if (result == DVDNAV_STATUS_ERR) {
             writeOutput(QString("ERR:Error getting next block: %1\n").arg(dvdnav_err_to_string(dvdnav)));
             emit sigError(i18n("Error getting next block: %1").arg(dvdnav_err_to_string(dvdnav)));
+            end();
             return;
         }
         switch (event) {
@@ -449,10 +472,10 @@ void k9play::play() {
                 bcell=true;
             } else {
                 if ((m_cell==0  || (m_cell!=0 && currCell==m_cell)) && !finished) {
-                    if (!vamps.isRunning())
-                        vamps.start(QThread::NormalPriority);
+                    if (!vamps->isRunning())
+                        vamps->start(QThread::NormalPriority);
                     bcopy=true;
-                    vamps.addData( buf,len);
+                    vamps->addData( buf,len);
                     status.bytesRead +=len;
                     writeOutput(QString("\rINFOPOS: %1 %2").arg((status.bytesRead+status.bytesSkipped) / DVD_VIDEO_LB_LEN).arg(lgr));
                     emit sigPosition((status.bytesRead+status.bytesSkipped) / DVD_VIDEO_LB_LEN,lgr);
@@ -467,9 +490,9 @@ void k9play::play() {
         case DVDNAV_BLOCK_OK:
             /* We have received a regular block of the currently playing MPEG stream.*/
             if (m_cell==0  || (m_cell!=0 && currCell==m_cell)) {
-                if (!vamps.isRunning())
-                    vamps.start(QThread::NormalPriority);
-                vamps.addData( buf,len);
+                if (!vamps->isRunning())
+                    vamps->start(QThread::NormalPriority);
+                vamps->addData( buf,len);
                 status.bytesRead +=len;
                 bcopy=true;
             }
@@ -548,8 +571,8 @@ void k9play::play() {
 
     }
     dvdnav_close(dvdnav);
-    vamps.setNoData();
-    vamps.wait();
+    vamps->setNoData();
+    vamps->wait();
     /* destroy dvdnav handle */
 
 
@@ -565,20 +588,29 @@ void k9play::play() {
         m_output->close();
         delete m_output;
     }
-    m_saveImage->stop();
+    if (!k9Tools::getBatchCopy()) m_saveImage->stop();
 
-    status.bytesWritten +=vamps.getOutputBytes();
+    status.bytesWritten +=vamps->getOutputBytes();
     if (!m_firstPass)
         saveStatus( status);
-    m_terminated=true;
+    end();
 
-    if (m_exitOnEnd)
-        qApp->exit();
-    if (m_eventLoop)
-        m_eventLoop->exit();
 
 }
 
+void k9play::end() {
+    m_terminated=true;
+    if (m_exitOnEnd) {
+        if (m_vamps->isRunning()) {
+            m_vamps->setNoData();
+            m_vamps->wait(1000);
+        }
+        delete m_vamps;
+        qApp->exit();
+    }
+    if (m_eventLoop)
+        m_eventLoop->exit();
+}
 
 bool k9play::readNavPack (k9DVDFile *fh, dsi_t *dsi,int sector,uchar *_buffer) {
     int n;
