@@ -33,12 +33,13 @@ typedef struct {
     uint64_t bytesChapters;
 } k9play_st;
 
-
+class k9vamps;
 
 class k9play:public QThread {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "k9copy.free.fr.player")
 private:
+    k9vamps *m_vamps;
     int m_title;
     k9DVD *m_dvd;
     k9DVDTitle *m_dvdTitle;
@@ -79,6 +80,7 @@ private:
     QEventLoop *m_eventLoop;
 protected:
     virtual void run(void);
+    void end();
 public:
     k9play(QObject *parent);
 
