@@ -154,7 +154,7 @@ void k9vamps::reset() {
 
 }
 
-k9vamps::k9vamps(k9DVDBackupInterface *dvdbackup,bool _useCache) {
+k9vamps::k9vamps(k9DVDBackupInterface *dvdbackup,bool _useCache):QThread(dvdbackup) {
 if (!_useCache)
     m_fifo=new k9MemoryFifo();
 else
